@@ -1,8 +1,11 @@
 package Panda::Config::Perl;
 use 5.012;
-use Panda::Lib();
+use Panda::Lib(); # XS code needs xs::lib::merge
 
-our $VERSION = '1.0.1';
+our $VERSION = '1.1.0';
+
+require Panda::XSLoader;
+Panda::XSLoader::load();
 
 sub process {
     my ($class, $file, $initial_cfg) = @_;
@@ -50,15 +53,15 @@ sub _process_file {
     $content =~ s/^[^\S\r\n]*#(namespace|namespace-abs|include)(?:[^\S\r\n]+(.+))?$/_process_directive($curdir, $ns, $1, $2)/gme;
     
     my $pkg = $ns ? "NS::$ns" : "NS";
-    $content = << "EOF";
-package $pkg; sub MERGE; *MERGE = \\&Panda::Lib::merge;
-$content
-;1;
-EOF
+    $content = "package $pkg; sub { $content }";
     my $ok;
     {
         no strict;
-        $ok = eval $content;
+        my $sub = eval $content;
+        if ($sub) {
+            tune_ops($sub);
+            $ok = eval { $sub->(); 1 };
+        }
     }
     unless ($ok) {
         my $err = $@;
@@ -81,7 +84,7 @@ sub _process_directive {
         $ns = '' if $directive eq 'namespace-abs';
         my $pkg = $ns ? "NS::$ns" : 'NS';
         $pkg .= "::$1" if $rest =~ /\s*(\S+)/;
-        return "package $pkg; sub MERGE; *MERGE = \\&Panda::Lib::hash_merge;";
+        return "package $pkg;";
     }
     elsif ($directive eq 'include') {
         return "Panda::Config::Perl::_INCLUDE('$curdir', __PACKAGE__, $rest);";
